@@ -17,6 +17,7 @@
 #include <pyside6_qtnetwork_python.h>
 
 // Bound library includes
+#include <QtMultimedia/qabstractvideobuffer.h>
 #include <QtMultimedia/qaudio.h>
 #include <QtMultimedia/qaudiodecoder.h>
 #include <QtMultimedia/qaudiodevice.h>
@@ -39,6 +40,8 @@
 
 QT_BEGIN_NAMESPACE
 class QAudioBuffer;
+class QAudioBufferInput;
+class QAudioBufferOutput;
 class QAudioInput;
 class QAudioOutput;
 class QAudioSink;
@@ -47,179 +50,190 @@ class QCameraFormat;
 class QCapturableWindow;
 class QMediaCaptureSession;
 class QMediaDevices;
+class QVideoFrameInput;
 class QVideoSink;
 QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
-    SBK_QAUDIO_ERROR_IDX                                     = 2,
-    SBK_QAUDIO_STATE_IDX                                     = 4,
-    SBK_QAUDIO_VOLUMESCALE_IDX                               = 6,
-    SBK_QTMULTIMEDIAQAUDIO_IDX                               = 0,
-    SBK_QAUDIOBUFFER_IDX                                     = 8,
-    SBK_QAUDIODECODER_ERROR_IDX                              = 12,
-    SBK_QAUDIODECODER_IDX                                    = 10,
-    SBK_QAUDIODEVICE_MODE_IDX                                = 16,
-    SBK_QAUDIODEVICE_IDX                                     = 14,
-    SBK_QAUDIOFORMAT_SAMPLEFORMAT_IDX                        = 24,
-    SBK_QAUDIOFORMAT_AUDIOCHANNELPOSITION_IDX                = 20,
-    SBK_QAUDIOFORMAT_CHANNELCONFIG_IDX                       = 22,
-    SBK_QAUDIOFORMAT_IDX                                     = 18,
-    SBK_QAUDIOINPUT_IDX                                      = 26,
-    SBK_QAUDIOOUTPUT_IDX                                     = 28,
-    SBK_QAUDIOSINK_IDX                                       = 30,
-    SBK_QAUDIOSOURCE_IDX                                     = 32,
-    SBK_QCAMERA_ERROR_IDX                                    = 36,
-    SBK_QCAMERA_FOCUSMODE_IDX                                = 44,
-    SBK_QCAMERA_FLASHMODE_IDX                                = 42,
-    SBK_QCAMERA_TORCHMODE_IDX                                = 46,
-    SBK_QCAMERA_EXPOSUREMODE_IDX                             = 38,
-    SBK_QCAMERA_WHITEBALANCEMODE_IDX                         = 48,
-    SBK_QCAMERA_FEATURE_IDX                                  = 40,
-    SBK_QFLAGS_QCAMERA_FEATURE_IDX                           = 58,
-    SBK_QCAMERA_IDX                                          = 34,
-    SBK_QCAMERADEVICE_POSITION_IDX                           = 52,
-    SBK_QCAMERADEVICE_IDX                                    = 50,
-    SBK_QCAMERAFORMAT_IDX                                    = 54,
-    SBK_QCAPTURABLEWINDOW_IDX                                = 56,
-    SBK_QIMAGECAPTURE_ERROR_IDX                              = 64,
-    SBK_QIMAGECAPTURE_QUALITY_IDX                            = 68,
-    SBK_QIMAGECAPTURE_FILEFORMAT_IDX                         = 66,
-    SBK_QIMAGECAPTURE_IDX                                    = 62,
-    SBK_QMEDIACAPTURESESSION_IDX                             = 70,
-    SBK_QMEDIADEVICES_IDX                                    = 72,
-    SBK_QMEDIAFORMAT_FILEFORMAT_IDX                          = 80,
-    SBK_QMEDIAFORMAT_AUDIOCODEC_IDX                          = 76,
-    SBK_QMEDIAFORMAT_VIDEOCODEC_IDX                          = 84,
-    SBK_QMEDIAFORMAT_CONVERSIONMODE_IDX                      = 78,
-    SBK_QMEDIAFORMAT_RESOLVEFLAGS_IDX                        = 82,
-    SBK_QMEDIAFORMAT_IDX                                     = 74,
-    SBK_QMEDIAMETADATA_KEY_IDX                               = 88,
-    SBK_QMEDIAMETADATA_IDX                                   = 86,
-    SBK_QMEDIAPLAYER_PLAYBACKSTATE_IDX                       = 98,
-    SBK_QMEDIAPLAYER_MEDIASTATUS_IDX                         = 96,
-    SBK_QMEDIAPLAYER_ERROR_IDX                               = 92,
-    SBK_QMEDIAPLAYER_LOOPS_IDX                               = 94,
-    SBK_QMEDIAPLAYER_IDX                                     = 90,
-    SBK_QMEDIARECORDER_QUALITY_IDX                           = 106,
-    SBK_QMEDIARECORDER_ENCODINGMODE_IDX                      = 102,
-    SBK_QMEDIARECORDER_RECORDERSTATE_IDX                     = 108,
-    SBK_QMEDIARECORDER_ERROR_IDX                             = 104,
-    SBK_QMEDIARECORDER_IDX                                   = 100,
-    SBK_QMEDIATIMERANGE_IDX                                  = 110,
-    SBK_QMEDIATIMERANGE_INTERVAL_IDX                         = 112,
-    SBK_QSCREENCAPTURE_ERROR_IDX                             = 116,
-    SBK_QSCREENCAPTURE_IDX                                   = 114,
-    SBK_QSOUNDEFFECT_LOOP_IDX                                = 120,
-    SBK_QSOUNDEFFECT_STATUS_IDX                              = 122,
-    SBK_QSOUNDEFFECT_IDX                                     = 118,
-    SBK_QVIDEOFRAME_HANDLETYPE_IDX                           = 126,
-    SBK_QVIDEOFRAME_MAPMODE_IDX                              = 128,
-    SBK_QVIDEOFRAME_ROTATIONANGLE_IDX                        = 134,
-    SBK_QVIDEOFRAME_IDX                                      = 124,
-    SBK_QVIDEOFRAME_PAINTOPTIONS_PAINTFLAG_IDX               = 132,
-    SBK_QFLAGS_QVIDEOFRAME_PAINTOPTIONS_PAINTFLAG_IDX        = 60,
-    SBK_QVIDEOFRAME_PAINTOPTIONS_IDX                         = 130,
-    SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX                    = 146,
-    SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX                      = 144,
-    SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX                = 148,
-    SBK_QVIDEOFRAMEFORMAT_COLORSPACE_IDX                     = 140,
-    SBK_QVIDEOFRAMEFORMAT_COLORTRANSFER_IDX                  = 142,
-    SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX                     = 138,
-    SBK_QVIDEOFRAMEFORMAT_IDX                                = 136,
-    SBK_QVIDEOSINK_IDX                                       = 150,
-    SBK_QWAVEDECODER_IDX                                     = 152,
-    SBK_QWINDOWCAPTURE_ERROR_IDX                             = 156,
-    SBK_QWINDOWCAPTURE_IDX                                   = 154,
-    SBK_QTVIDEO_ROTATION_IDX                                 = 160,
-    SBK_QTMULTIMEDIAQTVIDEO_IDX                              = 158,
-    SBK_QTMULTIMEDIA_IDX_COUNT                               = 162,
+    SBK_QABSTRACTVIDEOBUFFER_IDX                             = 0,
+    SBK_QABSTRACTVIDEOBUFFER_MAPDATA_IDX                     = 2,
+    SBK_QAUDIO_ERROR_IDX                                     = 6,
+    SBK_QAUDIO_STATE_IDX                                     = 8,
+    SBK_QAUDIO_VOLUMESCALE_IDX                               = 10,
+    SBK_QTMULTIMEDIAQAUDIO_IDX                               = 4,
+    SBK_QAUDIOBUFFER_IDX                                     = 12,
+    SBK_QAUDIOBUFFERINPUT_IDX                                = 14,
+    SBK_QAUDIOBUFFEROUTPUT_IDX                               = 16,
+    SBK_QAUDIODECODER_ERROR_IDX                              = 20,
+    SBK_QAUDIODECODER_IDX                                    = 18,
+    SBK_QAUDIODEVICE_MODE_IDX                                = 24,
+    SBK_QAUDIODEVICE_IDX                                     = 22,
+    SBK_QAUDIOFORMAT_SAMPLEFORMAT_IDX                        = 32,
+    SBK_QAUDIOFORMAT_AUDIOCHANNELPOSITION_IDX                = 28,
+    SBK_QAUDIOFORMAT_CHANNELCONFIG_IDX                       = 30,
+    SBK_QAUDIOFORMAT_IDX                                     = 26,
+    SBK_QAUDIOINPUT_IDX                                      = 34,
+    SBK_QAUDIOOUTPUT_IDX                                     = 36,
+    SBK_QAUDIOSINK_IDX                                       = 38,
+    SBK_QAUDIOSOURCE_IDX                                     = 40,
+    SBK_QCAMERA_ERROR_IDX                                    = 44,
+    SBK_QCAMERA_FOCUSMODE_IDX                                = 52,
+    SBK_QCAMERA_FLASHMODE_IDX                                = 50,
+    SBK_QCAMERA_TORCHMODE_IDX                                = 54,
+    SBK_QCAMERA_EXPOSUREMODE_IDX                             = 46,
+    SBK_QCAMERA_WHITEBALANCEMODE_IDX                         = 56,
+    SBK_QCAMERA_FEATURE_IDX                                  = 48,
+    SBK_QFLAGS_QCAMERA_FEATURE_IDX                           = 66,
+    SBK_QCAMERA_IDX                                          = 42,
+    SBK_QCAMERADEVICE_POSITION_IDX                           = 60,
+    SBK_QCAMERADEVICE_IDX                                    = 58,
+    SBK_QCAMERAFORMAT_IDX                                    = 62,
+    SBK_QCAPTURABLEWINDOW_IDX                                = 64,
+    SBK_QIMAGECAPTURE_ERROR_IDX                              = 72,
+    SBK_QIMAGECAPTURE_QUALITY_IDX                            = 76,
+    SBK_QIMAGECAPTURE_FILEFORMAT_IDX                         = 74,
+    SBK_QIMAGECAPTURE_IDX                                    = 70,
+    SBK_QMEDIACAPTURESESSION_IDX                             = 78,
+    SBK_QMEDIADEVICES_IDX                                    = 80,
+    SBK_QMEDIAFORMAT_FILEFORMAT_IDX                          = 88,
+    SBK_QMEDIAFORMAT_AUDIOCODEC_IDX                          = 84,
+    SBK_QMEDIAFORMAT_VIDEOCODEC_IDX                          = 92,
+    SBK_QMEDIAFORMAT_CONVERSIONMODE_IDX                      = 86,
+    SBK_QMEDIAFORMAT_RESOLVEFLAGS_IDX                        = 90,
+    SBK_QMEDIAFORMAT_IDX                                     = 82,
+    SBK_QMEDIAMETADATA_KEY_IDX                               = 96,
+    SBK_QMEDIAMETADATA_IDX                                   = 94,
+    SBK_QMEDIAPLAYER_PLAYBACKSTATE_IDX                       = 106,
+    SBK_QMEDIAPLAYER_MEDIASTATUS_IDX                         = 104,
+    SBK_QMEDIAPLAYER_ERROR_IDX                               = 100,
+    SBK_QMEDIAPLAYER_LOOPS_IDX                               = 102,
+    SBK_QMEDIAPLAYER_IDX                                     = 98,
+    SBK_QMEDIARECORDER_QUALITY_IDX                           = 114,
+    SBK_QMEDIARECORDER_ENCODINGMODE_IDX                      = 110,
+    SBK_QMEDIARECORDER_RECORDERSTATE_IDX                     = 116,
+    SBK_QMEDIARECORDER_ERROR_IDX                             = 112,
+    SBK_QMEDIARECORDER_IDX                                   = 108,
+    SBK_QMEDIATIMERANGE_IDX                                  = 118,
+    SBK_QMEDIATIMERANGE_INTERVAL_IDX                         = 120,
+    SBK_QSCREENCAPTURE_ERROR_IDX                             = 124,
+    SBK_QSCREENCAPTURE_IDX                                   = 122,
+    SBK_QSOUNDEFFECT_LOOP_IDX                                = 128,
+    SBK_QSOUNDEFFECT_STATUS_IDX                              = 130,
+    SBK_QSOUNDEFFECT_IDX                                     = 126,
+    SBK_QVIDEOFRAME_HANDLETYPE_IDX                           = 134,
+    SBK_QVIDEOFRAME_MAPMODE_IDX                              = 136,
+    SBK_QVIDEOFRAME_ROTATIONANGLE_IDX                        = 142,
+    SBK_QVIDEOFRAME_IDX                                      = 132,
+    SBK_QVIDEOFRAME_PAINTOPTIONS_PAINTFLAG_IDX               = 140,
+    SBK_QFLAGS_QVIDEOFRAME_PAINTOPTIONS_PAINTFLAG_IDX        = 68,
+    SBK_QVIDEOFRAME_PAINTOPTIONS_IDX                         = 138,
+    SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX                    = 154,
+    SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX                      = 152,
+    SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX                = 156,
+    SBK_QVIDEOFRAMEFORMAT_COLORSPACE_IDX                     = 148,
+    SBK_QVIDEOFRAMEFORMAT_COLORTRANSFER_IDX                  = 150,
+    SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX                     = 146,
+    SBK_QVIDEOFRAMEFORMAT_IDX                                = 144,
+    SBK_QVIDEOFRAMEINPUT_IDX                                 = 158,
+    SBK_QVIDEOSINK_IDX                                       = 160,
+    SBK_QWAVEDECODER_IDX                                     = 162,
+    SBK_QWINDOWCAPTURE_ERROR_IDX                             = 166,
+    SBK_QWINDOWCAPTURE_IDX                                   = 164,
+    SBK_QTVIDEO_ROTATION_IDX                                 = 170,
+    SBK_QTMULTIMEDIAQTVIDEO_IDX                              = 168,
+    SBK_QTMULTIMEDIA_IDX_COUNT                               = 172,
 };
 
 // Type indices
 enum : int {
-    SBK_QAudio_Error_IDX                                     = 1,
-    SBK_QAudio_State_IDX                                     = 2,
-    SBK_QAudio_VolumeScale_IDX                               = 3,
-    SBK_QtMultimediaQAudio_IDX                               = 0,
-    SBK_QAudioBuffer_IDX                                     = 4,
-    SBK_QAudioDecoder_Error_IDX                              = 6,
-    SBK_QAudioDecoder_IDX                                    = 5,
-    SBK_QAudioDevice_Mode_IDX                                = 8,
-    SBK_QAudioDevice_IDX                                     = 7,
-    SBK_QAudioFormat_SampleFormat_IDX                        = 12,
-    SBK_QAudioFormat_AudioChannelPosition_IDX                = 10,
-    SBK_QAudioFormat_ChannelConfig_IDX                       = 11,
-    SBK_QAudioFormat_IDX                                     = 9,
-    SBK_QAudioInput_IDX                                      = 13,
-    SBK_QAudioOutput_IDX                                     = 14,
-    SBK_QAudioSink_IDX                                       = 15,
-    SBK_QAudioSource_IDX                                     = 16,
-    SBK_QCamera_Error_IDX                                    = 18,
-    SBK_QCamera_FocusMode_IDX                                = 22,
-    SBK_QCamera_FlashMode_IDX                                = 21,
-    SBK_QCamera_TorchMode_IDX                                = 23,
-    SBK_QCamera_ExposureMode_IDX                             = 19,
-    SBK_QCamera_WhiteBalanceMode_IDX                         = 24,
-    SBK_QCamera_Feature_IDX                                  = 20,
-    SBK_QFlags_QCamera_Feature_IDX                           = 29,
-    SBK_QCamera_IDX                                          = 17,
-    SBK_QCameraDevice_Position_IDX                           = 26,
-    SBK_QCameraDevice_IDX                                    = 25,
-    SBK_QCameraFormat_IDX                                    = 27,
-    SBK_QCapturableWindow_IDX                                = 28,
-    SBK_QImageCapture_Error_IDX                              = 32,
-    SBK_QImageCapture_Quality_IDX                            = 34,
-    SBK_QImageCapture_FileFormat_IDX                         = 33,
-    SBK_QImageCapture_IDX                                    = 31,
-    SBK_QMediaCaptureSession_IDX                             = 35,
-    SBK_QMediaDevices_IDX                                    = 36,
-    SBK_QMediaFormat_FileFormat_IDX                          = 40,
-    SBK_QMediaFormat_AudioCodec_IDX                          = 38,
-    SBK_QMediaFormat_VideoCodec_IDX                          = 42,
-    SBK_QMediaFormat_ConversionMode_IDX                      = 39,
-    SBK_QMediaFormat_ResolveFlags_IDX                        = 41,
-    SBK_QMediaFormat_IDX                                     = 37,
-    SBK_QMediaMetaData_Key_IDX                               = 44,
-    SBK_QMediaMetaData_IDX                                   = 43,
-    SBK_QMediaPlayer_PlaybackState_IDX                       = 49,
-    SBK_QMediaPlayer_MediaStatus_IDX                         = 48,
-    SBK_QMediaPlayer_Error_IDX                               = 46,
-    SBK_QMediaPlayer_Loops_IDX                               = 47,
-    SBK_QMediaPlayer_IDX                                     = 45,
-    SBK_QMediaRecorder_Quality_IDX                           = 53,
-    SBK_QMediaRecorder_EncodingMode_IDX                      = 51,
-    SBK_QMediaRecorder_RecorderState_IDX                     = 54,
-    SBK_QMediaRecorder_Error_IDX                             = 52,
-    SBK_QMediaRecorder_IDX                                   = 50,
-    SBK_QMediaTimeRange_IDX                                  = 55,
-    SBK_QMediaTimeRange_Interval_IDX                         = 56,
-    SBK_QScreenCapture_Error_IDX                             = 58,
-    SBK_QScreenCapture_IDX                                   = 57,
-    SBK_QSoundEffect_Loop_IDX                                = 60,
-    SBK_QSoundEffect_Status_IDX                              = 61,
-    SBK_QSoundEffect_IDX                                     = 59,
-    SBK_QVideoFrame_HandleType_IDX                           = 63,
-    SBK_QVideoFrame_MapMode_IDX                              = 64,
-    SBK_QVideoFrame_RotationAngle_IDX                        = 67,
-    SBK_QVideoFrame_IDX                                      = 62,
-    SBK_QVideoFrame_PaintOptions_PaintFlag_IDX               = 66,
-    SBK_QFlags_QVideoFrame_PaintOptions_PaintFlag_IDX        = 30,
-    SBK_QVideoFrame_PaintOptions_IDX                         = 65,
-    SBK_QVideoFrameFormat_PixelFormat_IDX                    = 73,
-    SBK_QVideoFrameFormat_Direction_IDX                      = 72,
-    SBK_QVideoFrameFormat_YCbCrColorSpace_IDX                = 74,
-    SBK_QVideoFrameFormat_ColorSpace_IDX                     = 70,
-    SBK_QVideoFrameFormat_ColorTransfer_IDX                  = 71,
-    SBK_QVideoFrameFormat_ColorRange_IDX                     = 69,
-    SBK_QVideoFrameFormat_IDX                                = 68,
-    SBK_QVideoSink_IDX                                       = 75,
-    SBK_QWaveDecoder_IDX                                     = 76,
-    SBK_QWindowCapture_Error_IDX                             = 78,
-    SBK_QWindowCapture_IDX                                   = 77,
-    SBK_QtVideo_Rotation_IDX                                 = 80,
-    SBK_QtMultimediaQtVideo_IDX                              = 79,
-    SBK_QtMultimedia_IDX_COUNT                               = 81,
+    SBK_QAbstractVideoBuffer_IDX                             = 0,
+    SBK_QAbstractVideoBuffer_MapData_IDX                     = 1,
+    SBK_QAudio_Error_IDX                                     = 3,
+    SBK_QAudio_State_IDX                                     = 4,
+    SBK_QAudio_VolumeScale_IDX                               = 5,
+    SBK_QtMultimediaQAudio_IDX                               = 2,
+    SBK_QAudioBuffer_IDX                                     = 6,
+    SBK_QAudioBufferInput_IDX                                = 7,
+    SBK_QAudioBufferOutput_IDX                               = 8,
+    SBK_QAudioDecoder_Error_IDX                              = 10,
+    SBK_QAudioDecoder_IDX                                    = 9,
+    SBK_QAudioDevice_Mode_IDX                                = 12,
+    SBK_QAudioDevice_IDX                                     = 11,
+    SBK_QAudioFormat_SampleFormat_IDX                        = 16,
+    SBK_QAudioFormat_AudioChannelPosition_IDX                = 14,
+    SBK_QAudioFormat_ChannelConfig_IDX                       = 15,
+    SBK_QAudioFormat_IDX                                     = 13,
+    SBK_QAudioInput_IDX                                      = 17,
+    SBK_QAudioOutput_IDX                                     = 18,
+    SBK_QAudioSink_IDX                                       = 19,
+    SBK_QAudioSource_IDX                                     = 20,
+    SBK_QCamera_Error_IDX                                    = 22,
+    SBK_QCamera_FocusMode_IDX                                = 26,
+    SBK_QCamera_FlashMode_IDX                                = 25,
+    SBK_QCamera_TorchMode_IDX                                = 27,
+    SBK_QCamera_ExposureMode_IDX                             = 23,
+    SBK_QCamera_WhiteBalanceMode_IDX                         = 28,
+    SBK_QCamera_Feature_IDX                                  = 24,
+    SBK_QFlags_QCamera_Feature_IDX                           = 33,
+    SBK_QCamera_IDX                                          = 21,
+    SBK_QCameraDevice_Position_IDX                           = 30,
+    SBK_QCameraDevice_IDX                                    = 29,
+    SBK_QCameraFormat_IDX                                    = 31,
+    SBK_QCapturableWindow_IDX                                = 32,
+    SBK_QImageCapture_Error_IDX                              = 36,
+    SBK_QImageCapture_Quality_IDX                            = 38,
+    SBK_QImageCapture_FileFormat_IDX                         = 37,
+    SBK_QImageCapture_IDX                                    = 35,
+    SBK_QMediaCaptureSession_IDX                             = 39,
+    SBK_QMediaDevices_IDX                                    = 40,
+    SBK_QMediaFormat_FileFormat_IDX                          = 44,
+    SBK_QMediaFormat_AudioCodec_IDX                          = 42,
+    SBK_QMediaFormat_VideoCodec_IDX                          = 46,
+    SBK_QMediaFormat_ConversionMode_IDX                      = 43,
+    SBK_QMediaFormat_ResolveFlags_IDX                        = 45,
+    SBK_QMediaFormat_IDX                                     = 41,
+    SBK_QMediaMetaData_Key_IDX                               = 48,
+    SBK_QMediaMetaData_IDX                                   = 47,
+    SBK_QMediaPlayer_PlaybackState_IDX                       = 53,
+    SBK_QMediaPlayer_MediaStatus_IDX                         = 52,
+    SBK_QMediaPlayer_Error_IDX                               = 50,
+    SBK_QMediaPlayer_Loops_IDX                               = 51,
+    SBK_QMediaPlayer_IDX                                     = 49,
+    SBK_QMediaRecorder_Quality_IDX                           = 57,
+    SBK_QMediaRecorder_EncodingMode_IDX                      = 55,
+    SBK_QMediaRecorder_RecorderState_IDX                     = 58,
+    SBK_QMediaRecorder_Error_IDX                             = 56,
+    SBK_QMediaRecorder_IDX                                   = 54,
+    SBK_QMediaTimeRange_IDX                                  = 59,
+    SBK_QMediaTimeRange_Interval_IDX                         = 60,
+    SBK_QScreenCapture_Error_IDX                             = 62,
+    SBK_QScreenCapture_IDX                                   = 61,
+    SBK_QSoundEffect_Loop_IDX                                = 64,
+    SBK_QSoundEffect_Status_IDX                              = 65,
+    SBK_QSoundEffect_IDX                                     = 63,
+    SBK_QVideoFrame_HandleType_IDX                           = 67,
+    SBK_QVideoFrame_MapMode_IDX                              = 68,
+    SBK_QVideoFrame_RotationAngle_IDX                        = 71,
+    SBK_QVideoFrame_IDX                                      = 66,
+    SBK_QVideoFrame_PaintOptions_PaintFlag_IDX               = 70,
+    SBK_QFlags_QVideoFrame_PaintOptions_PaintFlag_IDX        = 34,
+    SBK_QVideoFrame_PaintOptions_IDX                         = 69,
+    SBK_QVideoFrameFormat_PixelFormat_IDX                    = 77,
+    SBK_QVideoFrameFormat_Direction_IDX                      = 76,
+    SBK_QVideoFrameFormat_YCbCrColorSpace_IDX                = 78,
+    SBK_QVideoFrameFormat_ColorSpace_IDX                     = 74,
+    SBK_QVideoFrameFormat_ColorTransfer_IDX                  = 75,
+    SBK_QVideoFrameFormat_ColorRange_IDX                     = 73,
+    SBK_QVideoFrameFormat_IDX                                = 72,
+    SBK_QVideoFrameInput_IDX                                 = 79,
+    SBK_QVideoSink_IDX                                       = 80,
+    SBK_QWaveDecoder_IDX                                     = 81,
+    SBK_QWindowCapture_Error_IDX                             = 83,
+    SBK_QWindowCapture_IDX                                   = 82,
+    SBK_QtVideo_Rotation_IDX                                 = 85,
+    SBK_QtMultimediaQtVideo_IDX                              = 84,
+    SBK_QtMultimedia_IDX_COUNT                               = 86,
 };
 
 // This variable stores all Python types exported by this module.
@@ -291,10 +305,14 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+template<> inline PyTypeObject *SbkType< ::QAbstractVideoBuffer >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QAbstractVideoBuffer::MapData >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAudio::Error >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudio_Error_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAudio::State >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudio_State_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAudio::VolumeScale >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudio_VolumeScale_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAudioBuffer >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QAudioBufferInput >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBufferInput_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QAudioBufferOutput >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBufferOutput_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAudioDecoder::Error >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDecoder_Error_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAudioDecoder >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDecoder_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAudioDevice::Mode >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_Mode_IDX]); }
@@ -365,6 +383,7 @@ template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorSpace >() { r
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorTransfer >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_ColorTransfer_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorRange >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_ColorRange_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QVideoFrameInput >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameInput_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QVideoSink >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoSink_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWaveDecoder >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QWaveDecoder_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWindowCapture::Error >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QWindowCapture_Error_IDX]); }
